@@ -14,12 +14,9 @@ from ex_dataclass.type_ import Field_
 from . import m
 
 
-
-
-
 def asdict(obj, *, dict_factory=dict):
     if not m.is_dataclass_instance(obj):
-        raise TypeError("asdict() should be called on dataclass instances")
+        raise TypeError("asdict() should be called on ex_dataclass instances")
     return __asdict_inner(obj, dict_factory)
 
 
@@ -27,12 +24,28 @@ def __asdict_inner(obj, dict_factory):
     if m.is_dataclass_instance(obj):
         result = []
         for f in m.fields(obj):
-            asdict_fn: m.asdict_func_type = getattr(obj, f"{m.AsdictFuncPrefix}_{f.name}", None)
-            if asdict_fn:
-                value = asdict_fn(getattr(obj, f.name, None))
-            else:
-                value = __asdict_inner(getattr(obj, f.name), dict_factory)
-            result.append((f.name, value))
+            dict_filed_name = f.label if f.label else f.name
+            if m.is_expack(obj):
+                asdict_fn: m.asdict_func_type = getattr(obj, f"{m.AsdictFuncPrefix}_{f.name}", None)
+                if asdict_fn:
+                    result.append(
+                            (dict_filed_name, asdict_fn(getattr(obj, f.name, None)))
+                    )
+
+                    continue
+                # fields_xx 存在于 expack
+                if hasattr(obj, "fields_xx"):
+                    filed_obj = obj.fields_xx.get(f.name, None)
+                    if filed_obj:
+                        if filed_obj.outside_field.asdict_factory:
+                            result.append(
+                                    (dict_filed_name,
+                                     filed_obj.outside_field.asdict_factory(getattr(obj, f.name, None)))
+                            )
+                            continue
+
+            value = __asdict_inner(getattr(obj, f.name), dict_factory)
+            result.append((dict_filed_name, value))
         return dict_factory(result)
 
     elif isinstance(obj, list):
@@ -46,23 +59,26 @@ def __asdict_inner(obj, dict_factory):
 
 
 class EXpack:
-
     # identification
     __ex_pack_field__ = m.EXPackField
 
     # reduce memory usage
-    __slots__ = ['fields', 'ex_debug']
+    __slots__ = ['__fields_xx', '__ex_debug_xx']
 
     def __init__(self, *args, **kwargs):
-        self.fields: typing.Dict[m.F_NAME, Field_] = {}
-        self.ex_debug = False
+        self.__fields_xx: typing.Dict[m.F_NAME, Field_] = {}
+        self.__ex_debug_xx = False
+
+    @property
+    def fields_xx(self) -> typing.Dict[m.F_NAME, Field_]:
+        return self.__fields_xx
 
     def _set_properties(self, fields: typing.Dict[m.F_NAME, Field_] = None) -> 'EXpack':
-        self.fields = fields
+        self.__fields_xx = fields
         return self
 
     def _with_debug(self, debug: bool) -> 'EXpack':
-        self.ex_debug = debug
+        self.__ex_debug_xx = debug
         return self
 
     def asdict(self) -> typing.Dict:
@@ -78,5 +94,3 @@ class EXpack:
     def pprint(self):
         import pprint
         pprint.pprint(asdict(self))
-
-
